@@ -84,7 +84,7 @@
 #define KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWIDGETSADDONS_NO_DEPRECATED
-#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
+#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57200
 #endif
 #ifdef KWIDGETSADDONS_NO_DEPRECATED_WARNINGS
 #  define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x56f00
+#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x57200
 #  endif
 #endif
 
